import { __awaiter } from "tslib";
import { assureDesignSystem } from '@genesislcap/foundation-utils';
/**
 * @remarks
 * Imports the rapid design system module.
 * @internal
 */
function rapidDesignSystemImport() {
    return __awaiter(this, void 0, void 0, function* () {
        const module = yield import(
        /* webpackChunkName: "rapid-design-system" */
        '@genesislcap/rapid-design-system');
        return assureDesignSystem(module);
    });
}
/**
 * @public
 */
export const registerCommonRapidComponents = () => __awaiter(void 0, void 0, void 0, function* () {
    const { provideDesignSystem, rapidIcon, rapidButton, designSystemProvider: rapidDesignSystemProvider, rapidSelect, rapidListboxOption, rapidFlyout, rapidConnectionIndicator, } = yield rapidDesignSystemImport();
    /**
     * Register the components the app is using with the system.
     */
    provideDesignSystem().register(
    /**
     * Design system provider element used to declaratively apply rapid config to every dom node in the host tree.
     */
    rapidDesignSystemProvider(), 
    /**
     * Common across most routes, so batch register these lightweight components upfront.
     */
    rapidIcon(), rapidButton(), rapidSelect(), rapidListboxOption(), rapidFlyout(), rapidConnectionIndicator);
});
